@@ -9,7 +9,7 @@ from graphviz import Digraph
 
 
 
-def Carto(Carto_tab_path=os.getcwd()+'cartographie.xlsx', Drop=True, view=True):
+def Carto(Carto_tab_path=os.getcwd()+'\\cartographie.xlsx', Drop=True, view=True):
 
 
     # Importation du fichier excel en dataframe
