@@ -2,7 +2,7 @@
 Contient la classe chargée de traiter, stocker et manipuler les informations liées aux tables.
 '''
 
-from src.BI_parser.variable import Variable
+from BI_parser.variable import Variable
 
 
 class Table(Variable):
